@@ -1,3 +1,6 @@
+/* max path length for bam */
+#define MAX_PATH_LENGTH 1024
+
 /* returns a pointer to the filename, /foo/bar.a -> bar.a */
 extern const char *path_filename(const char *path);
 
@@ -8,7 +11,7 @@ extern int path_directory(const char *path, char *directory, int size);
 extern int path_normalize(char *path);
 
 /* joins to paths together and normalizes them. returns 0 on success */
-extern int path_join(const char *base, const char *extend, char *output, int size);
+extern int path_join(const char *base, int base_len, const char *extend, int extend_len, char *output, int size);
 
 /* returns 1 if the path is absolute, else it returns 0 */
 extern int path_isabs(const char *path);
@@ -24,9 +27,10 @@ struct lua_State;
 extern int lf_path_isnice(struct lua_State *L);
 extern int lf_path_isabs(struct lua_State *L);
 extern int lf_path_join(struct lua_State *L);
-extern int lf_path_fix(struct lua_State *L);
+extern int lf_path_normalize(struct lua_State *L);
 
 extern int lf_path_ext(struct lua_State *L);
-extern int lf_path_path(struct lua_State *L);
+extern int lf_path_dir(struct lua_State *L);
+extern int lf_path_base(struct lua_State *L);
 extern int lf_path_filename(struct lua_State *L);
 
